@@ -17,10 +17,11 @@
  *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-static char rcsid[] = "$Id: io-bktr.c,v 1.4 2003/10/21 20:53:05 mschimek Exp $";
+static const char rcsid [] =
+"$Id: io-bktr.c,v 1.12 2005/01/24 00:11:53 mschimek Exp $";
 
 #ifdef HAVE_CONFIG_H
-#  include "../config.h"
+#  include "config.h"
 #endif
 
 #include "vbi.h"
@@ -33,13 +34,10 @@ static char rcsid[] = "$Id: io-bktr.c,v 1.4 2003/10/21 20:53:05 mschimek Exp $";
 #include <string.h>
 #include <math.h>
 #include <errno.h>
-#include <fcntl.h>
 #include <unistd.h>
 #include <assert.h>
 #include <sys/time.h>		/* timeval */
 #include <sys/select.h>		/* fd_set */
-#include <sys/ioctl.h>
-#include <sys/mman.h>
 #include <pthread.h>
 
 #define printv(format, args...)						\
@@ -71,7 +69,7 @@ static int
 bktr_read			(vbi_capture *		vc,
 				 vbi_capture_buffer **	raw,
 				 vbi_capture_buffer **	sliced,
-				 struct timeval *	timeout)
+				 const struct timeval *	timeout)
 {
 	vbi_capture_bktr *v = PARENT(vc, vbi_capture_bktr, capture);
 	vbi_capture_buffer *my_raw = v->raw_buffer;
@@ -161,8 +159,10 @@ bktr_delete(vbi_capture *vc)
 	for (; v->num_raw_buffers > 0; v->num_raw_buffers--)
 		free(v->raw_buffer[v->num_raw_buffers - 1].data);
 
-	if (v->fd != -1)
-		close(v->fd);
+	vbi_raw_decoder_destroy (&v->dec);
+
+	if (-1 != v->fd)
+		device_close (v->capture.sys_log_fp, v->fd);
 
 	free(v);
 }
@@ -183,6 +183,7 @@ vbi_capture_bktr_new		(const char *		dev_name,
 				 char **		errstr,
 				 vbi_bool		trace)
 {
+	char *error = NULL;
 	char *driver_name = _("BKTR driver");
 	vbi_capture_bktr *v;
 
@@ -190,22 +191,29 @@ vbi_capture_bktr_new		(const char *		dev_name,
 
 	assert(services && *services != 0);
 
-	printv("Try to open bktr vbi device, libzvbi interface rev.\n"
-	       "%s", rcsid);
+	if (!errstr)
+		errstr = &error;
+	*errstr = NULL;
+
+	printv ("Try to open bktr vbi device, "
+		"libzvbi interface rev.\n%s\n", rcsid);
 
 	if (!(v = (vbi_capture_bktr *) calloc(1, sizeof(*v)))) {
 		vbi_asprintf(errstr, _("Virtual memory exhausted."));
 		errno = ENOMEM;
-		return NULL;
+		goto failure;
 	}
 
+	vbi_raw_decoder_init (&v->dec);
+
 	v->capture.parameters = bktr_parameters;
 	v->capture._delete = bktr_delete;
 	v->capture.get_fd = bktr_fd;
 
-	if ((v->fd = open(dev_name, O_RDONLY)) == -1) {
-		vbi_asprintf(errstr, _("Cannot open '%s': %d, %s."),
-			     dev_name, errno, strerror(errno));
+	v->fd = device_open (v->capture.sys_log_fp, dev_name, O_RDONLY, 0);
+	if (-1 == v->fd) {
+		vbi_asprintf(errstr, _("Cannot open '%s': %s."),
+			     dev_name, strerror(errno));
 		goto io_error;
 	}
 
@@ -224,14 +232,13 @@ vbi_capture_bktr_new		(const char *		dev_name,
 	v->dec.count[0]	= 16;
 	v->dec.count[1] = 16;
 
-	switch (v->dec.scanning) {
+	switch (scanning) {
 	default:
-		v->dec.scanning = 625;
-
 		/* fall through */
 
 	case 625:
 		/* Not confirmed */
+		v->dec.scanning = 625;
 		v->dec.sampling_rate = 35468950;
 		v->dec.offset = (int)(10.2e-6 * 35468950);
 		v->dec.start[0] = 22 + 1 - v->dec.count[0];
@@ -240,6 +247,7 @@ vbi_capture_bktr_new		(const char *		dev_name,
 
 	case 525:
 		/* Not confirmed */
+		v->dec.scanning = 525;
 		v->dec.sampling_rate = 28636363;
 		v->dec.offset = (int)(9.2e-6 * 28636363);
 		v->dec.start[0] = 10;
@@ -314,11 +322,22 @@ vbi_capture_bktr_new		(const char *		dev_name,
 	printv("Successful opened %s (%s)\n",
 	       dev_name, driver_name);
 
+	if (errstr == &error) {
+		free (error);
+		error = NULL;
+	}
+
 	return &v->capture;
 
 failure:
 io_error:
-	bktr_delete(&v->capture);
+	if (v)
+		bktr_delete(&v->capture);
+
+	if (errstr == &error) {
+		free (error);
+		error = NULL;
+	}
 
 	return NULL;
 }
@@ -340,9 +359,10 @@ io_error:
  *   description here. You must free() this string when no longer needed.
  * @param trace If @c TRUE print progress messages on stderr.
  * 
- * @bug This seems to work only when video capturing is active
- * (tested with xawtv). Something I overlooked or a driver feature?
- *
+ * @bug You must enable continuous video capturing to read VBI data from
+ * the bktr driver, using an RGB video format, and the VBI device must be
+ * opened before video capturing starts (METEORCAPTUR).
+ * 
  * @return
  * Initialized vbi_capture context, @c NULL on failure.
  */
@@ -354,9 +374,14 @@ vbi_capture_bktr_new		(const char *		dev_name,
 				 char **		errstr,
 				 vbi_bool		trace)
 {
+	if (0) /* unused, no warning please */
+		fputs (rcsid, stderr);
+
 	pthread_once (&vbi_init_once, vbi_init);
 
-	vbi_asprintf(errstr, _("BKTR driver interface not compiled."));
+	if (errstr)
+		vbi_asprintf (errstr,
+			      _("BKTR driver interface not compiled."));
 
 	return NULL;
 }
