@@ -18,7 +18,7 @@
  *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: capture.c,v 1.16 2005/02/25 18:34:47 mschimek Exp $ */
+/* $Id: capture.c,v 1.18 2005/05/25 02:27:16 mschimek Exp $ */
 
 #undef NDEBUG
 
@@ -400,6 +400,9 @@ binary_ts_pes			(vbi_dvb_mux *		mx,
 				 const uint8_t *	packet,
 				 unsigned int		packet_size)
 {
+	mx = mx;
+	user_data = user_data;
+
 	fwrite (packet, 1, packet_size, stdout);
 	return TRUE;
 }
@@ -483,7 +486,7 @@ mainloop(void)
 	}
 }
 
-static const char short_options[] = "123de:lnpstvPT";
+static const char short_options[] = "123d:elnpstvPT";
 
 #ifdef HAVE_GETOPT_LONG
 static const struct option
@@ -518,7 +521,7 @@ long_options[] = {
 int
 main(int argc, char **argv)
 {
-	char *dev_name = "/dev/vbi";
+	char *dev_name;
 	int pid = -1;
 	char *errstr;
 	unsigned int services;
@@ -528,6 +531,9 @@ main(int argc, char **argv)
 	int c, index;
 	int interface = 0;
 
+	dev_name = strdup ("/dev/vbi");
+	assert (NULL != dev_name);
+
 	while ((c = getopt_long(argc, argv, short_options,
 				long_options, &index)) != -1)
 		switch (c) {
@@ -542,7 +548,9 @@ main(int argc, char **argv)
 			interface = c - '0';
 			break;
 		case 'd':
-			dev_name = optarg;
+			free (dev_name);
+			dev_name = strdup (optarg);
+			assert (NULL != dev_name);
 			break;
 		case 'e':
 			ignore_error ^= TRUE;
