@@ -18,7 +18,7 @@
  *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: decode.c,v 1.3 2005/02/25 18:32:19 mschimek Exp $ */
+/* $Id: decode.c,v 1.5 2005/05/26 04:07:33 mschimek Exp $ */
 
 #undef NDEBUG
 
@@ -47,6 +47,7 @@ static vbi_bool			dump_idl	= FALSE;
 static vbi_bool			dump_vps	= FALSE;
 static vbi_bool			dump_vps_r	= FALSE;
 static vbi_bool			dump_wss	= FALSE;
+static vbi_bool			dump_xds	= FALSE;
 static vbi_bool			dump_network	= FALSE;
 static vbi_bool			dump_hex	= FALSE;
 static vbi_bool			dump_bin	= FALSE;
@@ -61,6 +62,7 @@ static unsigned int		idl_address	= 0;
 static vbi_pfc_demux *		pfc;
 static vbi_dvb_demux *		dvb;
 static vbi_idl_demux *		idl;
+static vbi_xds_demux *		xds;
 
 extern void
 _vbi_pfc_block_dump		(const vbi_pfc_block *	pb,
@@ -81,6 +83,32 @@ vbi_printable			(int			c)
 	return c;
 }
 
+static vbi_bool
+xds_cb				(vbi_xds_demux *	xd,
+				 const vbi_xds_packet *	xp,
+				 void *			user_data)
+{
+
+	xd = xd;
+	user_data = user_data;
+
+	_vbi_xds_packet_dump (xp, stdout);
+
+	return TRUE; /* no errors */
+}
+
+static void
+caption				(const uint8_t		buffer[2],
+				 unsigned int		line)
+{
+	if (dump_xds && 284 == line) {
+		if (!vbi_xds_demux_feed (xds, buffer)) {
+			printf ("Parity error in XDS data\n");
+			return;
+		}
+	}
+}
+
 #if 0
 
 static void
@@ -201,22 +229,28 @@ packet_8302			(const uint8_t		buffer[42],
 #endif
 
 static vbi_bool
-page_function_clear		(vbi_pfc_demux *	pfc,
+page_function_clear_cb		(vbi_pfc_demux *	pfc,
 		                 const vbi_pfc_block *	block,
 				 void *			user_data)
 {
+	pfc = pfc;
+	user_data = user_data;
+
 	_vbi_pfc_block_dump (block, stdout, dump_bin);
 
 	return TRUE;
 }
 
 static vbi_bool
-idl_format_a			(vbi_idl_demux *	idl,
+idl_format_a_cb			(vbi_idl_demux *	idl,
 				 const uint8_t *	buffer,
 				 unsigned int		n_bytes,
 				 unsigned int		flags,
 				 void *			user_data)
 {
+	idl = idl;
+	user_data = user_data;
+
 	if (!dump_bin)
 		printf ("IDL-A%s%s ",
 			(flags & VBI_IDL_DATA_LOST) ? " <data lost>" : "",
@@ -536,6 +570,7 @@ decode				(const vbi_sliced *	s,
 		case VBI_SLICED_CAPTION_525_F1:
 		case VBI_SLICED_CAPTION_525_F2:
 		case VBI_SLICED_CAPTION_525:
+			caption (s->data, s->line);
 			break;
 
 		case VBI_SLICED_WSS_625:
@@ -673,7 +708,7 @@ abort:
 }
 
 static const char
-short_options [] = "12abc:d:hinp:rs:tvwxPTV";
+short_options [] = "12abc:d:ehinp:rs:tvwxPTV";
 
 #ifdef HAVE_GETOPT_LONG
 static const struct option
@@ -684,6 +719,7 @@ long_options [] = {
 	{ "bin",	no_argument,		NULL,		'b' },
 	{ "idl-ch",	required_argument,	NULL,		'c' },
 	{ "idl-addr",	required_argument,	NULL,		'd' },
+	{ "xds",	no_argument,		NULL,		'e' },
 	{ "help",	no_argument,		NULL,		'h' },
 	{ "idl",	no_argument,		NULL,		'i' },
 	{ "network",	no_argument,		NULL,		'n' },
@@ -724,6 +760,7 @@ usage				(FILE *			fp,
 		 "               Decode Teletext IDL format A data from\n"
 		 "               channel N (for example 8), service packet\n"
 		 "               address NNN (default is 0)\n"
+		 "-e | --xds     Decode eXtended Data Service data\n"
 		 "-i | --idl     Any Teletext IDL packets (M/30, M/31)\n"
 		 "-t | --ttx     Decode any Teletext packet\n"
 #if 0
@@ -799,6 +836,10 @@ main				(int			argc,
 			idl_address = strtol (optarg, NULL, 10);
 			break;
 
+		case 'e':
+			dump_xds ^= TRUE;
+			break;
+
 		case 'h':
 			usage (stdout, argv);
 			exit (EXIT_SUCCESS);
@@ -863,17 +904,27 @@ main				(int			argc,
 	}
 
 	if (0 != pfc_pgno) {
-		pfc = vbi_pfc_demux_new (pfc_pgno, pfc_stream,
-					 page_function_clear, NULL);
+		pfc = vbi_pfc_demux_new (pfc_pgno,
+					 pfc_stream,
+					 page_function_clear_cb,
+					 /* user_data */ NULL);
 		assert (NULL != pfc);
 	}
 
 	if (0 != idl_channel) {
-		idl = vbi_idl_a_demux_new (idl_channel, idl_address,
-					   idl_format_a, NULL);
+		idl = vbi_idl_a_demux_new (idl_channel,
+					   idl_address,
+					   idl_format_a_cb,
+					   /* user_data */ NULL);
 		assert (NULL != idl);
 	}
 
+	if (dump_xds) {
+		xds = vbi_xds_demux_new (xds_cb,
+					 /* used_data */ NULL);
+		assert (NULL != xds);
+	}
+
 	c = getchar ();
 	ungetc (c, stdin);
 
